/* -*- Mode: C; c-basic-offset: 2; indent-tabs-mode: nil -*-
 *
 * Pigment Render base library
 *
 * Copyright © 2006 Fluendo Embedded S.L. <www.fluendo.com>
 * All rights reserved.
 *
 * This file is available under one of two license agreements.
 *
 * This file is licensed under the GPL version 2. See "LICENSE.GPL" in
 * the root of this distribution including a special exception to use
 * Pigment with Fluendo's plugins.
 *
 * The GPL part of Pigment is also available under a commercial licensing
 * agreement from Fluendo. See "LICENSE.Pigment" in the root directory
 * of this distribution package for details on that license.
 */

#ifndef __PGM_RENDER_SINK_H__
#define __PGM_RENDER_SINK_H__

#if HAVE_CONFIG_H
#  include "config.h"
#endif /* HAVE_CONFIG_H */

#include "pgmrendererror.h"
#include "pgmrenderdrawable.h"
#include "pgmrendermedia-iface.h"
#include <gst/gst.h>
#include <gst/video/video.h>
#include <gst/video/gstvideosink.h>

G_BEGIN_DECLS

#define PGM_RENDER_TYPE_SINK (pgm_render_sink_get_type())
#define PGM_RENDER_SINK(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST((obj), PGM_RENDER_TYPE_SINK, PgmRenderSink))
#define PGM_RENDER_SINK_CLASS(klass) \
  (G_TYPE_CHECK_CLASS_CAST((klass), PGM_RENDER_TYPE_SINK, PgmRenderSink))
#define PGM_RENDER_IS_SINK(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE((obj), PGM_RENDER_TYPE_SINK))
#define PGM_RENDER_IS_SINK_CLASS(obj) \
  (G_TYPE_CHECK_CLASS_TYPE((klass), PGM_RENDER_TYPE_SINK))

typedef struct _PgmRenderSink PgmRenderSink;
typedef struct _PgmRenderSinkClass PgmRenderSinkClass;
typedef struct _FourccList FourccList;
typedef struct _RgbList RgbList;

struct _PgmRenderSink {
  GstVideoSink              base_element;

  PgmRenderDrawable         *drawable;
  PgmRenderMediaPixelFormat format;
  GMutex                    *mutex;
  GstPad                    *sink_pad;
  GstClockTime              time;
  gint                      framerate_n;
  gint                      framerate_d;
  gint                      width;
  gint                      height;
  gint                      stride;
};

struct _PgmRenderSinkClass {
  GstVideoSinkClass  parent_class;
};

struct _FourccList {
  const gchar               *fourcc;
  PgmRenderMediaPixelFormat format;
};

struct _RgbList {
  const gchar               *rgb;
  gint                      bpp;
  gint                      depth;
  guint                     red_mask;
  guint                     green_mask;
  guint                     blue_mask;
  guint                     alpha_mask;
  PgmRenderMediaPixelFormat format;
};

GType pgm_render_sink_get_type (void) G_GNUC_CONST;

G_END_DECLS

#endif /* __PGM_RENDER_SINK_H__ */
