/* -*- Mode: C; c-basic-offset: 2; indent-tabs-mode: nil -*-
 *
 * Pigment Render base library
 *
 * Copyright © 2006 Fluendo Embedded S.L. <www.fluendo.com>
 * All rights reserved.
 *
 * This file is available under one of two license agreements.
 *
 * This file is licensed under the GPL version 2. See "LICENSE.GPL" in
 * the root of this distribution including a special exception to use
 * Pigment with Fluendo's plugins.
 *
 * The GPL part of Pigment is also available under a commercial licensing
 * agreement from Fluendo. See "LICENSE.Pigment" in the root directory
 * of this distribution package for details on that license.
 */

#ifndef __PGM_RENDER_TEXT_IFACE_H__
#define __PGM_RENDER_TEXT_IFACE_H__

#include "pgmrendererror.h"
#include <glib-object.h>

G_BEGIN_DECLS

#define PGM_RENDER_TYPE_TEXT_IFACE             (pgm_render_text_iface_get_type ())
#define PGM_RENDER_TEXT_IFACE(obj)             (G_TYPE_CHECK_INSTANCE_CAST((obj), PGM_RENDER_TYPE_TEXT_IFACE, PgmRenderTextIFace))
#define PGM_RENDER_TEXT_IFACE_CLASS(vtable)    (G_TYPE_CHECK_CLASS_CAST((vtable), PGM_RENDER_TYPE_TEXT_IFACE, GTypeInterface))
#define PGM_RENDER_IS_TEXT_IFACE(obj)          (G_TYPE_CHECK_INSTANCE_TYPE((obj), PGM_RENDER_TYPE_TEXT_IFACE))
#define PGM_RENDER_IS_TEXT_IFACE_CLASS(vtable) (G_TYPE_CHECK_CLASS_TYPE((vtable), PGM_RENDER_TYPE_TEXT_IFACE))
#define PGM_RENDER_TEXT_IFACE_GET_CLASS(inst)  (G_TYPE_INSTANCE_GET_INTERFACE((inst), PGM_RENDER_TYPE_TEXT_IFACE, PgmRenderTextIFaceClass))

/**
 * PgmRenderTextWeight:
 * @PGM_RENDER_TEXT_WEIGHT_NORMAL: Normal text weight.
 * @PGM_RENDER_TEXT_WEIGHT_BOLD: Bold text weight.
 *
 * The different text weight types.
 */
typedef enum {
  PGM_RENDER_TEXT_WEIGHT_NORMAL,
  PGM_RENDER_TEXT_WEIGHT_BOLD
} PgmRenderTextWeight;

/**
 * PgmRenderTextSlant:
 * @PGM_RENDER_TEXT_SLANT_NORMAL: Normal text slant.
 * @PGM_RENDER_TEXT_SLANT_ITALIC: Italic text slant.
 *
 * The different text slant types.
 */
typedef enum {
  PGM_RENDER_TEXT_SLANT_NORMAL,
  PGM_RENDER_TEXT_SLANT_ITALIC
} PgmRenderTextSlant;

typedef struct _PgmRenderTextIFace      PgmRenderTextIFace;
typedef struct _PgmRenderTextIFaceClass PgmRenderTextIFaceClass;

struct _PgmRenderTextIFaceClass {
  GTypeInterface parent;

  PgmRenderError (*set_label) (PgmRenderTextIFace *text, const gchar *label);
  PgmRenderError (*get_label) (PgmRenderTextIFace *text, gchar *label);
  PgmRenderError (*set_font)  (PgmRenderTextIFace *text, const gchar *name, PgmRenderTextWeight weight, PgmRenderTextSlant slant, gint size);
  PgmRenderError (*get_font)  (PgmRenderTextIFace *text, PgmRenderTextWeight *weight, PgmRenderTextSlant *slant, gint *size);
  PgmRenderError (*set_color) (PgmRenderTextIFace *text, guchar r, guchar g, guchar b, guchar a);
  PgmRenderError (*get_color) (PgmRenderTextIFace *text, guchar *r, guchar *g, guchar *b, guchar *a);
  PgmRenderError (*get_size)  (PgmRenderTextIFace *text, gint *text_width, gint *text_height);
};

GType          pgm_render_text_iface_get_type (void) G_GNUC_CONST;
PgmRenderError pgm_render_text_set_label      (PgmRenderTextIFace *text, const gchar *label);
PgmRenderError pgm_render_text_get_label      (PgmRenderTextIFace *text, gchar *label);
PgmRenderError pgm_render_text_set_font       (PgmRenderTextIFace *text, const gchar *name, PgmRenderTextWeight weight, PgmRenderTextSlant slant, gint size);
PgmRenderError pgm_render_text_get_font       (PgmRenderTextIFace *text, PgmRenderTextWeight *weight, PgmRenderTextSlant *slant, gint *size);
PgmRenderError pgm_render_text_set_color      (PgmRenderTextIFace *text, guchar r, guchar g, guchar b, guchar a);
PgmRenderError pgm_render_text_get_color      (PgmRenderTextIFace *text, guchar *r, guchar *g, guchar *b, guchar *a);
PgmRenderError pgm_render_text_get_size       (PgmRenderTextIFace *text, gint *text_width, gint *text_height);

G_END_DECLS

#endif /* __PGM_RENDER_TEXT_IFACE_H__ */
