/* -*- Mode: C; c-basic-offset: 2; indent-tabs-mode: nil -*-
 *
 * Pigment Render OpenGL 1.2 plugin
 *
 * Copyright © 2006 Fluendo Embedded S.L. <www.fluendo.com>
 * All rights reserved.
 *
 * This file is available under one of two license agreements.
 *
 * This file is licensed under the GPL version 2. See "LICENSE.GPL" in
 * the root of this distribution including a special exception to use
 * Pigment with Fluendo's plugins.
 *
 * The GPL part of Pigment is also available under a commercial licensing
 * agreement from Fluendo. See "LICENSE.Pigment" in the root directory
 * of this distribution package for details on that license.
 *
 * Author: Loïc Molinari <loic@fluendo.com>
 */

#ifndef __PGM_RENDER_GL1_SURFACE_H__
#define __PGM_RENDER_GL1_SURFACE_H__

/* FIXME: Correct use of the autotools */
#include "pgmrendergl1.h"

G_BEGIN_DECLS

#define PGM_RENDER_TYPE_GL1_SURFACE            (pgm_render_gl1_surface_get_type())
#define PGM_RENDER_GL1_SURFACE(obj)            (G_TYPE_CHECK_INSTANCE_CAST((obj), PGM_RENDER_TYPE_GL1_SURFACE, PgmRenderGl1Surface))
#define PGM_RENDER_GL1_SURFACE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST((klass), PGM_RENDER_TYPE_GL1_SURFACE, Drawable))
#define PGM_RENDER_IS_GL1_SURFACE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE((obj), PGM_RENDER_TYPE_GL1_SURFACE))
#define PGM_RENDER_IS_GL1_SURFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), PGM_RENDER_TYPE_GL1_SURFACE))
#define PGM_RENDER_GL1_SURFACE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), PGM_RENDER_TYPE_GL1_SURFACE, PgmRenderGl1SurfaceClass))

typedef struct _PgmRenderGl1Surface PgmRenderGl1Surface;
typedef struct _PgmRenderGl1SurfaceClass PgmRenderGl1SurfaceClass;

struct _PgmRenderGl1Surface {
  PgmRenderDrawable          parent;

  /* Media interface */
  Color                      color[4];
  gint                       media_width;
  gint                       media_height;
  gint                       media_stride;
  gfloat                     media_ratio;
  gint                       media_pot_width;
  gint                       media_pot_height;
  PgmRenderGl1Surface        *media_master;
  GList                      *media_slave;
  PgmRenderMediaPixelFormat  media_format;
  gboolean                   media_loaded;
  gboolean                   media_gst_loaded;

  gfloat                     *media_tile_vertex;
  gfloat                     *media_tile_tex_coord;
  PgmRenderTextureObject     *media_texture;
  gint                       media_nb_width_tiles;
  gint                       media_nb_height_tiles;
  gint                       media_nb_tiles;
  gfloat                     media_width_texel_size;
  gfloat                     media_height_texel_size;
  gfloat                     media_last_tile_s;
  gfloat                     media_last_tile_t;
  PgmRenderGLenum            media_interp;
  gint                       max_texture_size;
  guchar                     *media_data;
  GstBuffer                  *media_gst_buffer;

  /* Layout interface */
  gint                       layout_width;
  gint                       layout_height;
  gint                       layout_x_position;
  gint                       layout_y_position;
  gfloat                     layout_ratio;
  gfloat                     layout_x_align;
  gfloat                     layout_y_align;
  PgmRenderLayoutAspectStyle layout_style;
  gfloat                     layout_custom_ratio;
  VertexCoord                vertex[4];
  /* FIXME: Using just one normal should be enough */
  /* Normal                     normal[4]; */

  /* Shape interface */
  VertexCoord                arc_vertex[40];
  gfloat                     arc_width;
  gfloat                     arc_height;
  gboolean                   use_arc;

  /* Stroke interface */
  gfloat                     stroke_width;
  Color                      stroke_color;
  PgmRenderStrokePattern     stroke_pattern;
  gint                       stroke_factor;

  /* Pipe3d interface */
  gfloat                     translation[3];
  gfloat                     rotation[3];

  gfloat                     sx, sy;
};

struct _PgmRenderGl1SurfaceClass {
  PgmRenderDrawableClass parent_class;

  PgmRenderGLenum    media_format_lut[8];
  gfloat             media_format_lut_size[8];

  GList              *surface_with_media_data;
  GList              *surface_with_media_gst_buffer;
  GList              *surface_with_new_media_interp;
  GList              *texture_trash;
};

GType                pgm_render_gl1_surface_get_type  (void) G_GNUC_CONST;
PgmRenderGl1Surface *pgm_render_gl1_surface_new       (void);
void                 pgm_render_gl1_surface_set_scale (PgmRenderGl1Surface *surface, gfloat sx, gfloat sy);

G_END_DECLS

#endif /* __PGM_RENDER_GL1_SURFACE_H__ */
